#include "complex.h"
#include "math.h"

Complex::Complex() : 
    re(0), im(0)
{}

Complex::Complex(double a) : 
    re(a), im(0)
{}

Complex::Complex(double a, double b) : 
    re(a), im(b)
{}

Complex::Complex(const Complex &a) : 
    re(a.re), im(a.im)
{}

double Complex::real() const
{
  return re;
}

double Complex::imaginary() const
{
  return im;
}

double Complex::module() const
{
  return sqrt(re * re + im * im);
}

Complex& Complex::operator=(const Complex &a)
{
  re = a.re;
  im = a.im;
  return *this;
}

Complex& Complex::operator+=(const Complex &a)
{
  re += a.re;
  im += a.im;
  return *this;
}

Complex& Complex::operator-=(const Complex &a)
{
  re -= a.re;
  im -= a.im;
  return *this;
}

const Complex operator+(const Complex &a, const Complex &b)
{
  return Complex(a.real() + b.real(), a.imaginary() + b.imaginary());
}


std::ostream& operator<<(std::ostream &o, const Complex &a)
{
  o << "{" << a.re << "," << a.im << "}";
  return o;
}
